# coding: utf-8

"""
    FastAPI

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from instalabel.client.models.attribute_selection import AttributeSelection
from typing import Optional, Set
from typing_extensions import Self

class ClassInformation(BaseModel):
    """
    Stores metadata about the class associated with an annotation.  Attributes:     id (str): The unique identifier for the class.     name (str): The name of the class.     color (str): The hexadecimal color associated with the class (used for visualization).     description (Optional[str]): A description of the class.     attributesSelectionsIdMap (Dict[str, List[str]]): A dictionary mapping attribute IDs to selected values.     attributesSelections (List[AttributeSelection]): A list of attribute selections for the class.
    """ # noqa: E501
    id: StrictStr = Field(description="The unique identifier for the class.")
    name: StrictStr = Field(description="The name of the class.")
    color: StrictStr = Field(description="The color associated with the class.")
    description: Optional[StrictStr] = None
    attributes_selections_id_map: Optional[Dict[str, List[StrictStr]]] = Field(default=None, description="A dictionary mapping attribute IDs to selected values.", alias="attributesSelectionsIdMap")
    attributes_selections: Optional[List[AttributeSelection]] = Field(default=None, description="A list of attribute selections for the class.", alias="attributesSelections")
    __properties: ClassVar[List[str]] = ["id", "name", "color", "description", "attributesSelectionsIdMap", "attributesSelections"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of ClassInformation from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of each item in attributes_selections (list)
        _items = []
        if self.attributes_selections:
            for _item_attributes_selections in self.attributes_selections:
                if _item_attributes_selections:
                    _items.append(_item_attributes_selections.to_dict())
            _dict['attributesSelections'] = _items
        # set to None if description (nullable) is None
        # and model_fields_set contains the field
        if self.description is None and "description" in self.model_fields_set:
            _dict['description'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of ClassInformation from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "id": obj.get("id"),
            "name": obj.get("name"),
            "color": obj.get("color"),
            "description": obj.get("description"),
            "attributesSelectionsIdMap": obj.get("attributesSelectionsIdMap"),
            "attributesSelections": [AttributeSelection.from_dict(_item) for _item in obj["attributesSelections"]] if obj.get("attributesSelections") is not None else None
        })
        return _obj


