# coding: utf-8

"""
    FastAPI

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from instalabel.client.models.workspace_in_db import WorkspaceInDB

class TestWorkspaceInDB(unittest.TestCase):
    """WorkspaceInDB unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> WorkspaceInDB:
        """Test WorkspaceInDB
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `WorkspaceInDB`
        """
        model = WorkspaceInDB()
        if include_optional:
            return WorkspaceInDB(
                workspace_id = '',
                workspace_name = '',
                owner_id = '',
                description = '',
                created_at = '',
                updated_at = '',
                product_id = '',
                credits = instalabel.client.models.workspace_credits.WorkspaceCredits(
                    image_uploads = instalabel.client.models.credit_limits.CreditLimits(
                        total = 56, 
                        used = 56, ), 
                    training_credits = instalabel.client.models.credit_limits.CreditLimits(
                        total = 56, 
                        used = 56, ), 
                    annotation_credits = , )
            )
        else:
            return WorkspaceInDB(
                workspace_name = '',
                owner_id = '',
                credits = instalabel.client.models.workspace_credits.WorkspaceCredits(
                    image_uploads = instalabel.client.models.credit_limits.CreditLimits(
                        total = 56, 
                        used = 56, ), 
                    training_credits = instalabel.client.models.credit_limits.CreditLimits(
                        total = 56, 
                        used = 56, ), 
                    annotation_credits = , ),
        )
        """

    def testWorkspaceInDB(self):
        """Test WorkspaceInDB"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
